**Example 1: 创建文件夹**



Input: 

```
tccli oceanus CreateFolder --cli-unfold-argument  \
    --FolderName test \
    --WorkSpaceId space-1257058945ap-guangzhou \
    --FolderType 0 \
    --ParentId root
```

Output: 
```
{
    "Response": {
        "FolderId": "folder-dhq5omrl",
        "RequestId": "a6030a9d-d791-4e7f-8f2c-7d908b6449a0"
    }
}
```

